#!/usr/bin/python
# -*- coding: utf-8 -*-
import SakaiPy.RequestGenerator



class Assignment(object):

    def __init__(self, rq):
        self.requester = rq

    def getAllAssignmentsForSite(self, siteid):
        return self.requester.executeRequest('/direct/assignment/site/{0}.json'.format(siteid))

    def getAllMyAssignments(self):
        return self.requester.executeRequest('/direct/assignment/my.json')

    def getAssignmentInfo(self, assignment_id):
        return self.requester.executeRequest('/direct/assignment/item/{0}.json'.format(assignment_id))






#!/usr/bin/python
# -*- coding: utf-8 -*-
import SakaiPy.RequestGenerator



class Forums(object):

    def __init__(self, rq):
        self.requester = rq

    def getForumsForSite(self, siteid):
        return self.requester.executeRequest('/direct/forums/site/{0}.json'.format(siteid))

    def getAllTopicsForForum(self, siteid, forumid):
        return self.requester.executeRequest('/direct/forums/site/{0}/forum/{1}.json'.format(siteid,
                forumid))

    def getAllConversationsForTopic(
        self,
        siteid,
        forumid,
        topicid,
        ):
        return self.requester.executeRequest('/direct/forums/site/{0}/forum/{1}/topic/{2}.json'.format(siteid,
                forumid, topicid))

    def getAllMessagesForConversation(
        self,
        siteid,
        forumid,
        topicid,
        messageid,
        ):
        return self.requester.executeRequest('/direct/forums/site/{0}/forum/{1}/topic/{2}/message/{3}.json'.format(siteid,
                forumid, topicid, messageid))



			


#!/usr/bin/python
# -*- coding: utf-8 -*-
import SakaiPy.RequestGenerator



class ContentResource(object):

    def __init__(self, rq):
        self.requester = rq

    def getContentsForSite(self, siteid):
        return self.requester.executeRequest('/direct/content/site/{0}.json'.format(siteid))

    def getMyWorkspaceContent(self):
        return self.requester.executeRequest('/direct/calendar/my.json'.format(siteid))


        



			


#!/usr/bin/python
# -*- coding: utf-8 -*-
import SakaiPy.RequestGenerator



class Gradebook(object):

	def __init__(self, rq):
        self.requester = rq



    def getAllMyGrades(self):
        return self.requester.executeRequest('/direct/calendar/my.json')


#!/usr/bin/python
# -*- coding: utf-8 -*-
import SakaiPy.RequestGenerator



class UserInfo(object):

	def __init__(self, rq):
        self.requester = rq

    def getUserInfoObjectByNetID(self,netid):
    	print "jhere"


	def getOwnUserInfo(self):
		


#!/usr/bin/python
# -*- coding: utf-8 -*-
import mechanize
import cookielib
import requests

try:
    import simplejson as json
except ImportError:
    import json

br = mechanize.Browser()

cj = cookielib.LWPCookieJar()

baseURL=""


class RequestGenerator(object):
    """This class will handle generating the neccasary requests and cookie generation"""

    # Browser

    br.set_cookiejar(cj)

    def __init__(self, connectionInfo):
        wPage = br.open(connectionInfo['loginURL'])
        self.baseURL=connectionInfo['baseURL']

        fCount=0

        for form in br.forms():
            if str(form.attrs["id"])==connectionInfo["loginFormId"]:
                break;
            fCount = fCount+1

        br.select_form(nr=fCount)

        br.form[connectionInfo['usernameField']] = connectionInfo['username']
        br.form[connectionInfo['passwordField']] = connectionInfo['password']
        br.submit()

    def executeRequest(self, url):
        """Returns the JSON response from the specified URL."""

        response = requests.get(self.baseURL+url, cookies=cj)

        if response.status_code == 200:
            return json.loads(response.content)
        else:
            return 'SHIT BROKE'



			


#!/usr/bin/python
# -*- coding: utf-8 -*-
import SakaiPy.RequestGenerator



class Roster(object):

    def __init__(self, rq):
        self.requester = rq

    def getSiteRoster(self, siteid):
        return self.requester.executeRequest('/direct/roster/site/{0}.json'.format(siteid))



			


#!/usr/bin/env python

from distutils.core import setup

setup(name='SakaiPy',
      version='1.1.0',
      description='Python interface to the Sakai RESTful API\'s',
      license='MIT',
      author='William Karavites',
      author_email='wkaravites@gmail.com',
      url='https://github.com/willkara/SakaiPy',
      packages=['SakaiPy','SakaiPy.SakaiTools'],
      install_requires={
      		"mechanize",
      		"requests",
      		"simplejson"},
      classifiers=[
            'Development Status :: 5 - Production/Stable',
            'Intended Audience :: Developers',
            'Intended Audience :: Education',
            'Intended Audience :: Information Technology',
            'License :: OSI Approved :: MIT License',
            'Natural Language :: English',
            'Operating System :: OS Independent',
            'Topic :: Education',
            'Topic :: Software Development :: Libraries :: Python Modules',
            'Programming Language :: Python :: 2.7',
            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3.0',
            'Programming Language :: Python :: 3.1',
            'Programming Language :: Python :: 3.2',
            'Programming Language :: Python :: 3.3',
            'Programming Language :: Python :: 3.4'


      ],
      keywords='Sakai Education RESTful'
     )
			



#!/usr/bin/python
# -*- coding: utf-8 -*-
import SakaiPy.RequestGenerator


class Calendar(object):

    def __init__(self, rq):
        self.requester = rq

    def getCalendarForSite(self, siteid):
        return self.requester.executeRequest('/direct/calendar/site/{0}.json'.format(siteid))

    def getAllMyEvents(self):
        return self.requester.executeRequest('/direct/calendar/my.json')

    def getEventDetails(self, siteid, eventid):
        return self.requester.executeRequest('/direct/calendar/event/{0}/{1}.json'.format(siteid,eventid))



